==> astro-1.0.15.tgz: package/src/utils/writeVirtualBackofficeExtensionFiles.ts <==
import { rm, writeFile } from 'node:fs/promises';
import { join, resolve } from 'node:path';
import { globby } from 'globby';
import { outdent } from 'outdent';
import { match } from 'variant';
import type { Component } from '../components.js';
import type { Model } from '../types.js';
import { isValidBackofficeComponent } from '../utils/isValidBackofficeComponent.js';

export async function writeVirtualBackofficeExtensionFiles(
  model: Model,
  codegenDir: string
) {
  const backofficeComponents = model.components.filter(
    isValidBackofficeComponent
  );

  const existingFiles = await globby(`*.astro`, {
    cwd: codegenDir,
    onlyFiles: true,
  });

  for (const filename of existingFiles) {
    const hasMatchingSourceFile = backofficeComponents.some(
      (component) => `${component.manifest.compId}.astro` === filename
    );

    if (hasMatchingSourceFile) {
      continue;
    }

    await rm(join(codegenDir, filename));
  }

  for (const component of backofficeComponents) {
    const entryFilename = resolveEntry(component);
    const originalEntrypoint = resolve(model.rootDir, entryFilename);
    const virtualEntrypoint = join(
      codegenDir,
      `${component.manifest.compId}.astro`
    );

    await writeFile(
      virtualEntrypoint,
      outdent`
        ---
        import Component from '${originalEntrypoint}';
        ---

        <div>
          <Component client:only="react" />
        </div>
      `
    );
  }
}

function resolveEntry(
  component:
    | Component<'BackofficeExtensionWidget'>
    | Component<'BackofficeModal'>
    | Component<'BackofficePage'>
) {
  const entryName = match(component, {
    BackofficeExtensionWidget: () => 'widget.tsx',
    BackofficeModal: () => 'modal.tsx',
    BackofficePage: () => 'page.tsx',
  });

  return join(component.directory, entryName);
}

==> astro-1.0.17.tgz: package/src/utils/writeVirtualBackofficeExtensionFiles.ts <==
import { rm, writeFile } from 'node:fs/promises';
import { join, resolve } from 'node:path';
import { globby } from 'globby';
import { outdent } from 'outdent';
import { match } from 'variant';
import type { Component } from '../components.js';
import type { Model } from '../types.js';
import { isValidBackofficeComponent } from '../utils/isValidBackofficeComponent.js';
import { toRelativePath } from './fs-utils.js';

export async function writeVirtualBackofficeExtensionFiles(
  model: Model,
  codegenDir: string
) {
  const backofficeComponents = model.components.filter(
    isValidBackofficeComponent
  );

  const existingFiles = await globby(`*.astro`, {
    cwd: codegenDir,
    onlyFiles: true,
  });

  for (const filename of existingFiles) {
    const hasMatchingSourceFile = backofficeComponents.some(
      (component) => `${component.manifest.compId}.astro` === filename
    );

    if (hasMatchingSourceFile) {
      continue;
    }

    await rm(join(codegenDir, filename));
  }

  for (const component of backofficeComponents) {
    const entryFilename = resolveEntry(component);
    const originalEntrypoint = resolve(model.rootDir, entryFilename);

    const virtualHocEntrypoint = join(
      codegenDir,
      `hoc_${component.manifest.compId}.tsx`
    );

    await writeFile(
      virtualHocEntrypoint,
      outdent`
        import Component from '${toRelativePath(originalEntrypoint, virtualHocEntrypoint)}';
        import { withContextualWixClient } from '@wix/dashboard/internal';

        export const WrappedComponent = withContextualWixClient(Component);
      `
    );

    const virtualEntrypoint = join(
      codegenDir,
      `${component.manifest.compId}.astro`
    );

    await writeFile(
      virtualEntrypoint,
      outdent`
        ---
        import { WrappedComponent } from '${toRelativePath(virtualHocEntrypoint, virtualEntrypoint)}';
        ---

        <div>
          <WrappedComponent client:only="react" />
        </div>
      `
    );
  }
}

function resolveEntry(
  component:
    | Component<'BackofficeExtensionWidget'>
    | Component<'BackofficeModal'>
    | Component<'BackofficePage'>
) {
  const entryName = match(component, {
    BackofficeExtensionWidget: () => 'widget.tsx',
    BackofficeModal: () => 'modal.tsx',
    BackofficePage: () => 'page.tsx',
  });

  return join(component.directory, entryName);
}
